@@ -11,6 +11,7 @@ TestCase.pytestmark = pytest.mark.django_db(transaction=True, reset_sequences=Tr
 def suppress_warnings():
     warnings.simplefilter("error", Warning)
     warnings.filterwarnings(
-        "ignore",
-        "name used for saved screenshot does not match file type",
-        UserWarning)
+        "ignore", "name used for saved screenshot does not match file type", UserWarning
+    )
+    warnings.filterwarnings("ignore", "'grappelli' defines default_app_config")
+    warnings.filterwarnings("ignore", "The distutils package")
