@@ -1,16 +1,20 @@
 from django.conf import settings
-from django.conf.urls import include, url
 from django.contrib import admin
 
+try:
+    from django.urls import re_path, include
+except ImportError:
+    from django.conf.urls import include, url as re_path
+
 # Explicitly import to register the admins for the test models
 for app in settings.INSTALLED_APPS:
-    if app.startswith('nested_admin.tests.'):
+    if app.startswith("nested_admin.tests."):
         __import__("%s.admin" % app)
 
 
 urlpatterns = [
-    url(r'^_nesting/', include('nested_admin.urls')),
-    url(r'^admin/', admin.site.urls),
+    re_path(r"^_nesting/", include("nested_admin.urls")),
+    re_path(r"^admin/", admin.site.urls),
 ]
 
 try:
@@ -18,4 +22,4 @@ try:
 except ImportError:
     pass
 else:
-    urlpatterns += [url(r"^grappelli/", include("grappelli.urls"))]
+    urlpatterns += [re_path(r"^grappelli/", include("grappelli.urls"))]
